@@ -1,6 +1,7 @@
 ;;; evenok.el --- Themes with perceptively evenly distributed colors  -*- lexical-binding: t; -*-
 
 ;; Copyright (C) 2024 Free Software Foundation, Inc.
+;; Copyright (C) 2026 Mekeor Melire
 
 ;; Author:                  Mekeor Melire <mekeor@posteo.de>
 ;; Created:                 2024
@@ -9,8 +10,8 @@
 ;; Maintainer:              Mekeor Melire <mekeor@posteo.de>
 ;; Package-Requires:        ((emacs "28.1"))
 ;; SPDX-License-Identifier: GPL-3.0-or-later
-;; Package-Version: 0.12.1
-;; Package-Revision: 5fc6494c4efb
+;; Package-Version: 20260120.2215
+;; Package-Revision: 541c44d35c8f
 
 ;; This file is NOT part of GNU Emacs.
 
@@ -210,6 +211,8 @@
            `(avy-lead-face-0                                      ((t :background ,white :foreground ,black :weight ,bold)))
            `(avy-lead-face-1                                      ((t :background ,white :foreground ,black :weight ,bold)))
            `(avy-lead-face-2                                      ((t :background ,white :foreground ,black :weight ,bold)))
+           `(battery-load-low                                     ((t :foreground ,bright-orange)))
+           `(battery-load-critical                                ((t :foreground ,bright-red)))
            `(bold                                                 ((t :weight ,bold)))
            `(bold-italic                                          ((t :slant italic :weight ,bold)))
            `(breadcrumb-face                                      ((t :foreground ,faded :slant italic :weight ,light)))
@@ -275,6 +278,20 @@
            `(custom-variable-obsolete                             ((t :foreground ,bright-red)))
            `(custom-variable-tag                                  ((t :foreground ,bright-yellow)))
            `(custom-visibility                                    ((t :underline t)))
+           `(debbugs-gnu-archived                                 ((t :foreground ,faded)))
+           `(debbugs-gnu-done                                     ((t :foreground ,bright-green)))
+           `(debbugs-gnu-forwarded                                ((t :foreground ,bright-purple)))
+           `(debbugs-gnu-handled                                  ((t :foreground ,bright-cyan)))
+           `(debbugs-gnu-marked                                   ((t :weight ,bold)))
+           `(debbugs-gnu-marked-stale                             ((t :foreground ,faded :weight ,bold)))
+           `(debbugs-gnu-new                                      ((t :background ,dark :extend t)))
+           `(debbugs-gnu-pending                                  ((t :foreground ,bright-orange)))
+           `(debbugs-gnu-stale-1                                  ((t :foreground ,faded)))
+           `(debbugs-gnu-stale-2                                  ((t :foreground ,faded)))
+           `(debbugs-gnu-stale-3                                  ((t :foreground ,faded)))
+           `(debbugs-gnu-stale-4                                  ((t :foreground ,faded)))
+           `(debbugs-gnu-stale-5                                  ((t :foreground ,faded)))
+           `(debbugs-gnu-tagged                                   ((t :foreground ,bright-blue)))
            `(debbugs-gnu-title                                    ((t :foreground ,white)))
            `(default                                              ((t :background ,black :foreground ,bright :weight ,normal)))
            `(devdocs-code-block                                   ((t :background ,dark :extend t)))
@@ -320,6 +337,7 @@
            `(dired-mark                                           ((t :foreground ,bright-orange)))
            `(dired-marked                                         ((t :foreground ,bright-orange)))
            `(dired-symlink                                        ((t :foreground ,bright-cyan)))
+           `(display-time-date-and-time                           ((t :foreground ,faded)))
            `(eat-shell-prompt-annotation-failure                  ((t :foreground ,bright-red)))
            `(eat-shell-prompt-annotation-running                  ((t :foreground ,bright-yellow)))
            `(eat-shell-prompt-annotation-success                  ((t :foreground ,bright-green)))
@@ -385,6 +403,30 @@
            `(embark-selected                                      ((t :inverse-video t :weight ,bold)))
            `(embark-target                                        ((t :inverse-video t :weight ,bold)))
            `(embark-verbose-indicator-title                       ((t :foreground ,white)))
+           `(ement-room-fully-read-marker                         ((t :foreground ,bright-green)))
+           `(ement-room-list-direct                               ((t :foreground ,bright-magenta)))
+           `(ement-room-list-favourite                            ((t :foreground ,bright-blue)))
+           `(ement-room-list-invited                              ((t :foreground ,bright-purple)))
+           `(ement-room-list-left                                 ((t :foreground ,bright-orange)))
+           `(ement-room-list-low-priority                         ((t :foreground ,faded)))
+           `(ement-room-list-unread                               ((t :foreground ,bright-yellow)))
+           `(ement-room-membership                                ((t :foreground ,faded)))
+           `(ement-room-mention                                   ((t :foreground ,bright-magenta)))
+           `(ement-room-quote                                     ((t :slant italic :weight ,light)))
+           `(ement-room-read-receipt-marker                       ((t :foreground ,bright-blue)))
+           `(ement-room-redacted                                  ((t :foreground ,bright-red)))
+           `(ement-room-self                                      ((t :foreground ,bright-cyan)))
+           `(ement-room-self-message                              ((t :foreground ,bright-cyan)))
+           `(ement-room-timestamp                                 ((t :foreground ,faded)))
+           `(ement-room-timestamp-header                          ((t :foreground ,faded)))
+           `(ement-room-user                                      ((t :foreground ,bright-yellow)))
+           `(ement-tabulated-room-list-direct                     ((t :foreground ,bright-red)))
+           `(ement-tabulated-room-list-favourite                  ((t :foreground ,bright-magenta)))
+           `(ement-tabulated-room-list-invited                    ((t :foreground ,bright-blue)))
+           `(ement-tabulated-room-list-left                       ((t :foreground ,bright-orange)))
+           `(ement-tabulated-room-list-low-priority               ((t :foreground ,faded)))
+           `(ement-tabulated-room-list-name                       ((t :foreground ,bright)))
+           `(ement-tabulated-room-list-unread                     ((t :foreground ,bright-yellow)))
            `(erc-button                                           ((t :underline t)))
            `(erc-current-nick-face                                ((t :foreground ,bright-red)))
            `(erc-my-nick-face                                     ((t :foreground ,bright-green)))
@@ -415,8 +457,12 @@
            `(eshell-syntax-highlighting-option-face               ((t :foreground ,bright-magenta)))
            `(eshell-syntax-highlighting-shell-command-face        ((t :foreground ,bright-blue)))
            `(eshell-syntax-highlighting-string-face               ((t :foreground ,bright-green)))
+           `(eww-form-text                                        ((t :background ,dark)))
+           `(eww-form-textarea                                    ((t :background ,dark)))
+           `(excerpt                                              ((t :slant italic)))
            `(file-name-shadow                                     ((t :foreground ,faded)))
-           `(fill-column-indicator                                ((t :foreground ,dim)))
+           `(fill-column-indicator                                ((t :background ,dim :height 1)))
+           `(fixed                                                ((t :weight ,bold)))
            `(flycheck-verify-select-checker                       ((t :underline t)))
            `(flymake-end-of-line-diagnostics-face                 ((t :foreground ,grey-red :slant italic :weight ,light)))
            `(flymake-error                                        ((t :underline (:color ,bright-red :style wave :position nil))))
@@ -432,7 +478,26 @@
            `(flymake-warning-echo-at-eol                          ((t :foreground ,grey-orange :weight ,light)))
            `(flyspell-duplicate                                   ((t :underline (:color ,faded-orange :style wave :position nil))))
            `(flyspell-incorrect                                   ((t :underline (:color ,faded-red :style wave :position nil))))
-           `(font-latex-math-face                                 ((t :background ,black)))
+           `(font-latex-bold-face                                 ((t :weight ,bold)))
+           `(font-latex-math-face                                 ((t :background ,black :foreground ,bright-yellow)))
+           `(font-latex-italic-face                               ((t :slant italic)))
+           `(font-latex-sedate-face                               ((t :foreground ,bright-purple)))
+           `(font-latex-string-face                               ((t :foreground ,bright-green)))
+           `(font-latex-warning-face                              ((t :foreground ,bright-orange)))
+           `(font-latex-verbatim-face                             ((t :foreground ,bright-cyan)))
+           `(font-latex-subscript-face                            ((t :foreground ,bright-blue)))
+           `(font-latex-underline-face                            ((t :underline t)))
+           `(font-latex-script-char-face                          ((t :foreground ,bright-magenta)))
+           `(font-latex-slide-title-face                          ((t :foreground ,white)))
+           `(font-latex-superscript-face                          ((t :foreground ,bright-blue)))
+           `(font-latex-sectioning-0-face                         ((t :foreground ,white)))
+           `(font-latex-sectioning-1-face                         ((t :foreground ,white)))
+           `(font-latex-sectioning-2-face                         ((t :foreground ,white)))
+           `(font-latex-sectioning-3-face                         ((t :foreground ,white)))
+           `(font-latex-sectioning-4-face                         ((t :foreground ,white)))
+           `(font-latex-sectioning-5-face                         ((t :foreground ,white)))
+           `(font-latex-doctex-preprocessor-face                  ((t :foreground ,faded)))
+           `(font-latex-doctex-documentation-face                 ((t :foreground ,faded)))
            `(font-lock-builtin-face                               ((t :foreground ,bright-cyan)))
            `(font-lock-comment-delimiter-face                     ((t :foreground ,faded :weight ,normal)))
            `(font-lock-comment-face                               ((t :foreground ,faded :weight ,normal)))
@@ -558,6 +623,17 @@
            `(line-number-current-line                             ((t :background ,dark :foreground ,dim :weight ,bold)))
            `(link                                                 ((t :underline t)))
            `(link-visited                                         ((t :underline t)))
+           `(lsp-face-semhl-comment                               ((t :foreground ,faded)))
+           `(lsp-face-semhl-constant                              ((t :foreground ,bright-orange)))
+           `(lsp-face-semhl-deprecated                            ((t :foreground ,bright-red)))
+           `(lsp-face-semhl-function                              ((t :foreground ,bright-blue)))
+           `(lsp-face-semhl-keyword                               ((t :foreground ,bright-magenta)))
+           `(lsp-face-semhl-macro                                 ((t :foreground ,bright-purple)))
+           `(lsp-face-semhl-number                                ((t :foreground ,bright-purple)))
+           `(lsp-face-semhl-regexp                                ((t :foreground ,bright-blue)))
+           `(lsp-face-semhl-string                                ((t :foreground ,bright-green)))
+           `(lsp-face-semhl-type                                  ((t :foreground ,bright-yellow)))
+           `(lsp-face-semhl-variable                              ((t :foreground ,bright-red)))
            `(magit-blame-heading                                  ((t :background ,dark :foreground ,bright :slant italic)))
            `(magit-branch-current                                 ((t :foreground ,bright-purple)))
            `(magit-branch-local                                   ((t :foreground ,bright-purple)))
@@ -837,11 +913,13 @@
            `(transient-heading                                    ((t :foreground ,white :weight ,bold)))
            `(transient-inactive-argument                          ((t :foreground ,faded)))
            `(transient-inactive-value                             ((t :foreground ,faded)))
-           `(transient-key                                        ((t :foreground ,white)))
-           `(transient-key-exit                                   ((t :foreground ,white)))
-           `(transient-key-noop                                   ((t :foreground ,white)))
-           `(transient-key-return                                 ((t :foreground ,white)))
-           `(transient-key-stay                                   ((t :foreground ,white)))
+           `(transient-key                                        ((t :foreground ,bright-magenta)))
+           `(transient-key-exit                                   ((t :foreground ,bright-red)))
+           `(transient-key-noop                                   ((t :foreground ,bright)))
+           `(transient-key-recurse                                ((t :foreground ,bright-cyan)))
+           `(transient-key-return                                 ((t :foreground ,bright-blue)))
+           `(transient-key-stack                                  ((t :foreground ,bright-purple)))
+           `(transient-key-stay                                   ((t :foreground ,bright-yellow)))
            `(transient-mismatched-key                             ((t :foreground ,bright-red)))
            `(transient-pink                                       ((t :foreground ,bright-magenta)))
            `(transient-purple                                     ((t :foreground ,bright-purple)))
@@ -875,9 +953,9 @@
            `(widget-documentation                                 ((t :underline t)))
            `(widget-field                                         ((t :background ,dark)))
            `(widget-inactive                                      ((t :foreground ,faded)))
-           `(window-divider                                       ((t :foreground ,dark)))
-           `(window-divider-first-pixel                           ((t :foreground ,dark)))
-           `(window-divider-last-pixel                            ((t :foreground ,dark)))
+           `(window-divider                                       ((t :foreground ,faded)))
+           `(window-divider-first-pixel                           ((t :foreground ,faded)))
+           `(window-divider-last-pixel                            ((t :foreground ,faded)))
            `(woman-addition                                       ((t :foreground ,bright-yellow)))
            `(woman-bold                                           ((t :foreground ,white)))
            `(woman-italic                                         ((t :slant italic)))
